@@ -40,25 +40,14 @@
  *
  * ***** END LICENSE BLOCK ***** */
 
-gTestfile = '9.2.1.2.js';
+gTestfile = '9.1.1.5.js';
 
-START("9.2.1.2 - XMLList [[Put]]");
+// XML Type [[Default Value]]
+START("9.1.1.5 - XML [[Default Value]]");
 
-var x =
-<>
-    <alpha>one</alpha>
-    <bravo>two</bravo>
-</>;
+var actual = 'Test not implemented';
+var expect = 'PASS';
 
-TEST(1, "<alpha>one</alpha>\n<bravo>two</bravo>",
-  x.toXMLString());
+TEST(1, expect, actual);
 
-x[0] = <charlie>three</charlie>;
-TEST(2, "<charlie>three</charlie>\n<bravo>two</bravo>",
-  x.toXMLString());
-
-x[0] = <delta>four</delta> + <echo>five</echo>;
-TEST(3, "<delta>four</delta>\n<echo>five</echo>\n<bravo>two</bravo>",
-  x.toXMLString());
-
-END();
\ No newline at end of file
+END();
