@@ -36,69 +36,42 @@
  *
  * ***** END LICENSE BLOCK ***** */
 
-gTestfile = '7.4.3-9-n.js';
+gTestfile = '7.4.2-16-n.js';
 
 /**
-   File Name:          7.4.3-9-n.js
-   ECMA Section:       7.4.3
+   File Name:          7.4.2-16-n.js
+   ECMA Section:       7.4.2
 
    Description:
-   The following words are used as keywords in proposed extensions and are
-   therefore reserved to allow for the possibility of future adoption of
-   those extensions.
+   The following tokens are ECMAScript keywords and may not be used as
+   identifiers in ECMAScript programs.
 
-   FutureReservedWord :: one of
-   case    debugger    export      super
-   catch   default     extends     switch
-   class   do          finally     throw
-   const   enum        import      try
+   Syntax
+
+   Keyword :: one of
+   break          for         new         var
+   continue       function    return      void
+   delete         if          this        while
+   else           in          typeof      with
+
+   This test verifies that the keyword cannot be used as an identifier.
+   Functioinal tests of the keyword may be found in the section corresponding
+   to the function of the keyword.
 
    Author:             christine@netscape.com
    Date:               12 november 1997
+
 */
-var SECTION = "7.4.3-9-n";
+var SECTION = "7.4.1-16-n";
 var VERSION = "ECMA_1";
 startTest();
-var TITLE   = "Future Reserved Words";
+var TITLE   = "Keywords";
 
 writeHeaderToLog( SECTION + " "+ TITLE);
 
-var actual = 'no error';
-var prefValue;
-
-DESCRIPTION = "var class = true";
+DESCRIPTION = "var with = true";
 EXPECTED = "error";
 
-
-print("This test requires option javascript.options.strict enabled");
-
-if (!options().match(/strict/))
-{
-  options('strict');
-}
-if (!options().match(/werror/))
-{
-  options('werror');
-}
-
-try
-{
-  eval("var class = true");
-}
-catch(e)
-{
-  actual = 'error';
-}
-
-// force exception since this is a negative test
-if (actual == 'error')
-{
-  throw actual;
-}
-
-new TestCase( SECTION, 
-              "var class = true",    
-              "error",   
-              actual );
+new TestCase( SECTION,  "var with = true",     "error",    eval("var with = true") );
 
 test();
