@@ -35,10 +35,10 @@
  *
  * ***** END LICENSE BLOCK ***** */
 
-var gTestfile = 'regress-355829-01.js';
+var gTestfile = 'regress-460886-02.js';
 //-----------------------------------------------------------------------------
-var BUGNUMBER = 355829;
-var summary = 'Do not assert: !argc || JSVAL_IS_NULL(argv[0]) || JSVAL_IS_VOID(argv[0])';
+var BUGNUMBER = 460886;
+var summary = 'Do not crash @ js_NewStringCopy';
 var actual = '';
 var expect = '';
 
@@ -53,8 +53,8 @@ function test()
   printBugNumber(BUGNUMBER);
   printStatus (summary);
 
-  new Object({valueOf: /a/});
-
+  for (var j = 0; j < 5; ++j) { "".substring(-60000); } 
+ 
   reportCompare(expect, actual, summary);
 
   exitFunc ('test');
