@@ -16,10 +16,10 @@
  *
  * The Initial Developer of the Original Code is
  * Mozilla Foundation.
- * Portions created by the Initial Developer are Copyright (C) 2008
+ * Portions created by the Initial Developer are Copyright (C) 2005
  * the Initial Developer. All Rights Reserved.
  *
- * Contributor(s): Mike Shaver
+ * Contributor(s): Igor Bukanov
  *
  * Alternatively, the contents of this file may be used under the terms of
  * either the GNU General Public License Version 2 or later (the "GPL"), or
@@ -35,34 +35,26 @@
  *
  * ***** END LICENSE BLOCK ***** */
 
-var gTestfile = 'regress-465980-01.js';
+var gTestfile = 'regress-310425-01.js';
 //-----------------------------------------------------------------------------
-var BUGNUMBER = 465980;
-var summary = 'Do not crash @ InitArrayElements';
+var BUGNUMBER = 310425;
+var summary = 'Array.indexOf/lastIndexOf edge cases';
 var actual = '';
 var expect = '';
 
+printBugNumber(BUGNUMBER);
+printStatus (summary);
+ 
+expect = -1;
+actual = [].lastIndexOf(undefined, -1);
+reportCompare(expect, actual, summary);
 
-//-----------------------------------------------------------------------------
-test();
-//-----------------------------------------------------------------------------
+expect = -1;
+actual = [].indexOf(undefined, -1);
+reportCompare(expect, actual, summary);
 
-function test()
-{
-  enterFunc ('test');
-  printBugNumber(BUGNUMBER);
-  printStatus (summary);
-
-  try
-  {
-    var a = new Array(4294967294);
-    a.push("foo", "bar");
-  }
-  catch(ex)
-  {
-  }
-
-  reportCompare(expect, actual, summary);
-
-  exitFunc ('test');
-}
+var x = [];
+x[1 << 30] = 1;
+expect = (1 << 30);
+actual = x.lastIndexOf(1);
+reportCompare(expect, actual, summary);
