@@ -35,35 +35,21 @@
  *
  * ***** END LICENSE BLOCK ***** */
 
-var gTestfile = 'regress-437288-01.js';
+var gTestfile = 'regress-476871-01.js';
 //-----------------------------------------------------------------------------
-var BUGNUMBER = 437288;
-var summary = 'for loop turning into a while loop';
-var actual = 'No Hang';
-var expect = 'No Hang';
+var BUGNUMBER = 476871;
+var summary = 'Do not assert: *(JSObject**)slot == NULL';
+var actual = '';
+var expect = '';
 
+printBugNumber(BUGNUMBER);
+printStatus (summary);
 
-//-----------------------------------------------------------------------------
-test();
-//-----------------------------------------------------------------------------
+jit(true);
 
-function test()
-{
-  enterFunc ('test');
-  printBugNumber(BUGNUMBER);
-  printStatus (summary);
+let ([] = false) { (this.watch("x", /a/g)); };
+(function () { (eval("(function(){for each (x in [1, 2, 2]);});"))(); })();
 
-  expect = 'SyntaxError: invalid for/in left-hand side';
-  try
-  {
-    eval('(function() { const x = 1; for (x in null); })();');
-  }
-  catch(ex)
-  {
-    actual = ex + '';
-  }
+jit(false);
 
-  reportCompare(expect, actual, summary);
-
-  exitFunc ('test');
-}
+reportCompare(expect, actual, summary);
