@@ -19,7 +19,7 @@
  * Portions created by the Initial Developer are Copyright (C) 2008
  * the Initial Developer. All Rights Reserved.
  *
- * Contributor(s): Jesse Ruderman
+ * Contributor(s): Brendan Eich
  *
  * Alternatively, the contents of this file may be used under the terms of
  * either the GNU General Public License Version 2 or later (the "GPL"), or
@@ -35,10 +35,10 @@
  *
  * ***** END LICENSE BLOCK ***** */
 
-var gTestfile = 'regress-466905-01.js';
+var gTestfile = 'regress-467495-03.js';
 //-----------------------------------------------------------------------------
-var BUGNUMBER = 466905;
-var summary = 'Do not assert: v_ins->isCall() && v_ins->callInfo() == &js_FastNewArray_ci';
+var BUGNUMBER = 467495;
+var summary = 'TCF_FUN_CLOSURE_VS_VAR is necessary';
 var actual = '';
 var expect = '';
 
@@ -52,12 +52,29 @@ function test()
   enterFunc ('test');
   printBugNumber(BUGNUMBER);
   printStatus (summary);
- 
-  function f(a) { for each (let c in a) [(c > 5) ? 'A' : 'B']; }
-  f([true, 8]);
-  f([2]);
 
-  reportCompare(expect, actual, summary);
+  function f(x)
+  {
+    actual = '';
+    var g;
+    print(actual += typeof g + ',');
+
+    if (x)
+      function g(){};
+
+    print(actual += g);
+  }
+
+  expect = 'undefined,undefined';
+  f(0);
+
+  reportCompare(expect, actual, summary + ': f(0): ');
+
+  expect = 'undefined,function g() {\n}';
+
+  f(1);
+
+  reportCompare(expect, actual, summary + ': f(1): ');
 
   exitFunc ('test');
 }
