@@ -42,7 +42,6 @@
 #define nsStyleConsts_h___
 
 #include "nsFont.h"
-#include "nsIWidget.h"
 
 // cairo doesn't support invert
 // #define GFX_HAS_INVERT
@@ -107,9 +106,6 @@
 #define NS_STYLE_FLOAT_EDGE_CONTENT       0
 #define NS_STYLE_FLOAT_EDGE_MARGIN        1
 
-// key-equivalent
-#define NS_STYLE_KEY_EQUIVALENT_NONE      0
-
 // user-focus
 #define NS_STYLE_USER_FOCUS_NONE            0
 #define NS_STYLE_USER_FOCUS_IGNORE          1
@@ -242,21 +238,16 @@
 #define NS_COLOR_MOZ_ACTIVEHYPERLINKTEXT        -3
 #define NS_COLOR_CURRENTCOLOR                   -4
 
-// See nsStyleBackground
-// 0x01 was background-color:transparent
-#define NS_STYLE_BG_IMAGE_NONE                  0x02
-#define NS_STYLE_BG_X_POSITION_PERCENT          0x04
-#define NS_STYLE_BG_X_POSITION_LENGTH           0x08
-#define NS_STYLE_BG_Y_POSITION_PERCENT          0x10
-#define NS_STYLE_BG_Y_POSITION_LENGTH           0x20
-
 // See nsStyleBackground
 #define NS_STYLE_BG_ATTACHMENT_SCROLL     0
 #define NS_STYLE_BG_ATTACHMENT_FIXED      1
 
 // See nsStyleBackground
+// Code depends on these constants having the same values as BG_ORIGIN_*
 #define NS_STYLE_BG_CLIP_BORDER           0
 #define NS_STYLE_BG_CLIP_PADDING          1
+// When we add NS_STYLE_BG_CLIP_CONTENT, we should add the PR_STATIC_ASSERTs
+// to the places that assert equality for BORDER and PADDING.
 
 // See nsStyleBackground
 #define NS_STYLE_BG_INLINE_POLICY_EACH_BOX      0
@@ -264,6 +255,7 @@
 #define NS_STYLE_BG_INLINE_POLICY_BOUNDING_BOX  2
 
 // See nsStyleBackground
+// Code depends on these constants having the same values as BG_CLIP_*
 #define NS_STYLE_BG_ORIGIN_BORDER         0
 #define NS_STYLE_BG_ORIGIN_PADDING        1
 #define NS_STYLE_BG_ORIGIN_CONTENT        2
@@ -277,11 +269,16 @@
 #define NS_STYLE_BG_POSITION_RIGHT   (1<<4)
 
 // See nsStyleBackground
+// Code depends on (BG_REPEAT_X | BG_REPEAT_Y) == BG_REPEAT_XY
 #define NS_STYLE_BG_REPEAT_OFF                  0x00
 #define NS_STYLE_BG_REPEAT_X                    0x01
 #define NS_STYLE_BG_REPEAT_Y                    0x02
 #define NS_STYLE_BG_REPEAT_XY                   0x03
 
+// See nsStyleBackground
+#define NS_STYLE_BG_SIZE_CONTAIN  0
+#define NS_STYLE_BG_SIZE_COVER    1
+
 // See nsStyleTable
 #define NS_STYLE_BORDER_COLLAPSE                0
 #define NS_STYLE_BORDER_SEPARATE                1
@@ -395,6 +392,7 @@
 #define NS_STYLE_DISPLAY_TABLE_CAPTION          17
 #define NS_STYLE_DISPLAY_BOX                    18
 #define NS_STYLE_DISPLAY_INLINE_BOX             19
+#ifdef MOZ_XUL
 #define NS_STYLE_DISPLAY_GRID                   20
 #define NS_STYLE_DISPLAY_INLINE_GRID            21
 #define NS_STYLE_DISPLAY_GRID_GROUP             22
@@ -404,6 +402,7 @@
 #define NS_STYLE_DISPLAY_DECK                   26
 #define NS_STYLE_DISPLAY_POPUP                  27
 #define NS_STYLE_DISPLAY_GROUPBOX               28
+#endif
 
 // See nsStyleDisplay
 #define NS_STYLE_FLOAT_NONE                     0
@@ -411,19 +410,22 @@
 #define NS_STYLE_FLOAT_RIGHT                    2
 
 // See nsStyleFont
-#define NS_STYLE_FONT_STYLE_NORMAL              0
-#define NS_STYLE_FONT_STYLE_ITALIC              1
-#define NS_STYLE_FONT_STYLE_OBLIQUE             2
+// We should eventually stop using the NS_STYLE_* variants here.
+#define NS_STYLE_FONT_STYLE_NORMAL              NS_FONT_STYLE_NORMAL
+#define NS_STYLE_FONT_STYLE_ITALIC              NS_FONT_STYLE_ITALIC
+#define NS_STYLE_FONT_STYLE_OBLIQUE             NS_FONT_STYLE_OBLIQUE
 
 // See nsStyleFont
-#define NS_STYLE_FONT_VARIANT_NORMAL            0
-#define NS_STYLE_FONT_VARIANT_SMALL_CAPS        1
+// We should eventually stop using the NS_STYLE_* variants here.
+#define NS_STYLE_FONT_VARIANT_NORMAL            NS_FONT_VARIANT_NORMAL
+#define NS_STYLE_FONT_VARIANT_SMALL_CAPS        NS_FONT_VARIANT_SMALL_CAPS
 
 // See nsStyleFont
-#define NS_STYLE_FONT_WEIGHT_NORMAL             400
-#define NS_STYLE_FONT_WEIGHT_BOLD               700
-#define NS_STYLE_FONT_WEIGHT_BOLDER             1
-#define NS_STYLE_FONT_WEIGHT_LIGHTER            -1
+// We should eventually stop using the NS_STYLE_* variants here.
+#define NS_STYLE_FONT_WEIGHT_NORMAL             NS_FONT_WEIGHT_NORMAL
+#define NS_STYLE_FONT_WEIGHT_BOLD               NS_FONT_WEIGHT_BOLD
+#define NS_STYLE_FONT_WEIGHT_BOLDER             NS_FONT_WEIGHT_BOLDER
+#define NS_STYLE_FONT_WEIGHT_LIGHTER            NS_FONT_WEIGHT_LIGHTER
 
 // See nsStyleFont
 #define NS_STYLE_FONT_SIZE_XXSMALL              0
@@ -438,17 +440,18 @@
 #define NS_STYLE_FONT_SIZE_SMALLER              9
 
 // See nsStyleFont
-#define NS_STYLE_FONT_STRETCH_ULTRA_CONDENSED   -4
-#define NS_STYLE_FONT_STRETCH_EXTRA_CONDENSED   -3
-#define NS_STYLE_FONT_STRETCH_CONDENSED         -2
-#define NS_STYLE_FONT_STRETCH_SEMI_CONDENSED    -1
-#define NS_STYLE_FONT_STRETCH_NORMAL            0
-#define NS_STYLE_FONT_STRETCH_SEMI_EXPANDED     1
-#define NS_STYLE_FONT_STRETCH_EXPANDED          2
-#define NS_STYLE_FONT_STRETCH_EXTRA_EXPANDED    3
-#define NS_STYLE_FONT_STRETCH_ULTRA_EXPANDED    4
-#define NS_STYLE_FONT_STRETCH_WIDER             10
-#define NS_STYLE_FONT_STRETCH_NARROWER          -10
+// We should eventually stop using the NS_STYLE_* variants here.
+#define NS_STYLE_FONT_STRETCH_ULTRA_CONDENSED   NS_FONT_STRETCH_ULTRA_CONDENSED
+#define NS_STYLE_FONT_STRETCH_EXTRA_CONDENSED   NS_FONT_STRETCH_EXTRA_CONDENSED
+#define NS_STYLE_FONT_STRETCH_CONDENSED         NS_FONT_STRETCH_CONDENSED
+#define NS_STYLE_FONT_STRETCH_SEMI_CONDENSED    NS_FONT_STRETCH_SEMI_CONDENSED
+#define NS_STYLE_FONT_STRETCH_NORMAL            NS_FONT_STRETCH_NORMAL
+#define NS_STYLE_FONT_STRETCH_SEMI_EXPANDED     NS_FONT_STRETCH_SEMI_EXPANDED
+#define NS_STYLE_FONT_STRETCH_EXPANDED          NS_FONT_STRETCH_EXPANDED
+#define NS_STYLE_FONT_STRETCH_EXTRA_EXPANDED    NS_FONT_STRETCH_EXTRA_EXPANDED
+#define NS_STYLE_FONT_STRETCH_ULTRA_EXPANDED    NS_FONT_STRETCH_ULTRA_EXPANDED
+#define NS_STYLE_FONT_STRETCH_WIDER             NS_FONT_STRETCH_WIDER
+#define NS_STYLE_FONT_STRETCH_NARROWER          NS_FONT_STRETCH_NARROWER
 
 // See nsStyleFont - system fonts
 #define NS_STYLE_FONT_CAPTION                   1		// css2
@@ -580,19 +583,34 @@
 // See nsStyleMargin
 #define NS_STYLE_MARGIN_SIZE_AUTO               0
 
+// See nsStyleDisplay
+#define NS_STYLE_POINTER_EVENTS_NONE            0
+#define NS_STYLE_POINTER_EVENTS_VISIBLEPAINTED  1
+#define NS_STYLE_POINTER_EVENTS_VISIBLEFILL     2
+#define NS_STYLE_POINTER_EVENTS_VISIBLESTROKE   3
+#define NS_STYLE_POINTER_EVENTS_VISIBLE         4
+#define NS_STYLE_POINTER_EVENTS_PAINTED         5
+#define NS_STYLE_POINTER_EVENTS_FILL            6
+#define NS_STYLE_POINTER_EVENTS_STROKE          7
+#define NS_STYLE_POINTER_EVENTS_ALL             8
+#define NS_STYLE_POINTER_EVENTS_AUTO            9
+
 // See nsStyleText
-// 
-// Note: make sure the numbers are less than the numbers that start
-// the vertical_align values below!
-#define NS_STYLE_TEXT_ALIGN_DEFAULT             0
-#define NS_STYLE_TEXT_ALIGN_LEFT                1
-#define NS_STYLE_TEXT_ALIGN_RIGHT               2
-#define NS_STYLE_TEXT_ALIGN_CENTER              3
-#define NS_STYLE_TEXT_ALIGN_JUSTIFY             4
-#define NS_STYLE_TEXT_ALIGN_CHAR                5   //align based on a certain character, for table cell
-#define NS_STYLE_TEXT_ALIGN_MOZ_CENTER          6
-#define NS_STYLE_TEXT_ALIGN_MOZ_RIGHT           7
-#define NS_STYLE_TEXT_ALIGN_MOZ_LEFT            8
+#define NS_STYLE_TEXT_ALIGN_DEFAULT               0
+#define NS_STYLE_TEXT_ALIGN_LEFT                  1
+#define NS_STYLE_TEXT_ALIGN_RIGHT                 2
+#define NS_STYLE_TEXT_ALIGN_CENTER                3
+#define NS_STYLE_TEXT_ALIGN_JUSTIFY               4
+#define NS_STYLE_TEXT_ALIGN_CHAR                  5   //align based on a certain character, for table cell
+#define NS_STYLE_TEXT_ALIGN_END                   6
+#define NS_STYLE_TEXT_ALIGN_MOZ_CENTER            7
+#define NS_STYLE_TEXT_ALIGN_MOZ_RIGHT             8
+#define NS_STYLE_TEXT_ALIGN_MOZ_LEFT              9
+// NS_STYLE_TEXT_ALIGN_MOZ_CENTER_OR_INHERIT is only used in data structs; it
+// is never present in stylesheets or computed data.
+#define NS_STYLE_TEXT_ALIGN_MOZ_CENTER_OR_INHERIT 10
+// Note: make sure that the largest NS_STYLE_TEXT_ALIGN_* value is smaller than
+// the smallest NS_STYLE_VERTICAL_ALIGN_* value below!
 
 // See nsStyleText, nsStyleFont
 #define NS_STYLE_TEXT_DECORATION_NONE           0
@@ -600,8 +618,10 @@
 #define NS_STYLE_TEXT_DECORATION_OVERLINE       NS_FONT_DECORATION_OVERLINE
 #define NS_STYLE_TEXT_DECORATION_LINE_THROUGH   NS_FONT_DECORATION_LINE_THROUGH
 #define NS_STYLE_TEXT_DECORATION_BLINK          0x08
-#define NS_STYLE_TEXT_DECORATION_OVERRIDE_ALL   0x10
-#define NS_STYLE_TEXT_DECORATION_PREF_ANCHORS   0x20
+#define NS_STYLE_TEXT_DECORATION_PREF_ANCHORS   0x10
+// OVERRIDE_ALL does not occur in stylesheets; it only comes from HTML
+// attribute mapping (and thus appears in computed data)
+#define NS_STYLE_TEXT_DECORATION_OVERRIDE_ALL   0x20
 #define NS_STYLE_TEXT_DECORATION_LINES_MASK     (NS_STYLE_TEXT_DECORATION_UNDERLINE | NS_STYLE_TEXT_DECORATION_OVERLINE | NS_STYLE_TEXT_DECORATION_LINE_THROUGH)
 
 // See nsStyleText
@@ -614,15 +634,15 @@
 // Note: these values pickup after the text-align values because there
 // are a few html cases where an object can have both types of
 // alignment applied with a single attribute
-#define NS_STYLE_VERTICAL_ALIGN_BASELINE             10
-#define NS_STYLE_VERTICAL_ALIGN_SUB                  11
-#define NS_STYLE_VERTICAL_ALIGN_SUPER                12
-#define NS_STYLE_VERTICAL_ALIGN_TOP                  13
-#define NS_STYLE_VERTICAL_ALIGN_TEXT_TOP             14
-#define NS_STYLE_VERTICAL_ALIGN_MIDDLE               15
-#define NS_STYLE_VERTICAL_ALIGN_TEXT_BOTTOM          16
-#define NS_STYLE_VERTICAL_ALIGN_BOTTOM               17
-#define NS_STYLE_VERTICAL_ALIGN_MIDDLE_WITH_BASELINE 18
+#define NS_STYLE_VERTICAL_ALIGN_BASELINE             11
+#define NS_STYLE_VERTICAL_ALIGN_SUB                  12
+#define NS_STYLE_VERTICAL_ALIGN_SUPER                13
+#define NS_STYLE_VERTICAL_ALIGN_TOP                  14
+#define NS_STYLE_VERTICAL_ALIGN_TEXT_TOP             15
+#define NS_STYLE_VERTICAL_ALIGN_MIDDLE               16
+#define NS_STYLE_VERTICAL_ALIGN_TEXT_BOTTOM          17
+#define NS_STYLE_VERTICAL_ALIGN_BOTTOM               18
+#define NS_STYLE_VERTICAL_ALIGN_MIDDLE_WITH_BASELINE 19
 
 // See nsStyleDisplay
 #define NS_STYLE_VISIBILITY_HIDDEN              0
@@ -640,6 +660,9 @@
 #define NS_STYLE_WORDWRAP_NORMAL                0
 #define NS_STYLE_WORDWRAP_BREAK_WORD            1
 
+// See nsStyleText
+#define NS_STYLE_LINE_HEIGHT_BLOCK_HEIGHT       0
+
 // See nsStyleText
 #define NS_STYLE_UNICODE_BIDI_NORMAL            0
 #define NS_STYLE_UNICODE_BIDI_EMBED             1
@@ -714,6 +737,16 @@
 #define NS_STYLE_IME_MODE_DISABLED              3
 #define NS_STYLE_IME_MODE_INACTIVE              4
 
+// See nsStyleGradient
+#define NS_STYLE_GRADIENT_SHAPE_LINEAR          0
+#define NS_STYLE_GRADIENT_SHAPE_ELLIPTICAL      1
+#define NS_STYLE_GRADIENT_SHAPE_CIRCULAR        2
+
+#define NS_STYLE_GRADIENT_SIZE_CLOSEST_SIDE     0
+#define NS_STYLE_GRADIENT_SIZE_CLOSEST_CORNER   1
+#define NS_STYLE_GRADIENT_SIZE_FARTHEST_SIDE    2
+#define NS_STYLE_GRADIENT_SIZE_FARTHEST_CORNER  3
+
 #ifdef MOZ_SVG
 // See nsStyleSVG
 
@@ -735,16 +768,11 @@
 #define NS_STYLE_FILL_RULE_NONZERO              0
 #define NS_STYLE_FILL_RULE_EVENODD              1
 
-// pointer-events
-#define NS_STYLE_POINTER_EVENTS_NONE            0
-#define NS_STYLE_POINTER_EVENTS_VISIBLEPAINTED  1
-#define NS_STYLE_POINTER_EVENTS_VISIBLEFILL     2
-#define NS_STYLE_POINTER_EVENTS_VISIBLESTROKE   3
-#define NS_STYLE_POINTER_EVENTS_VISIBLE         4
-#define NS_STYLE_POINTER_EVENTS_PAINTED         5
-#define NS_STYLE_POINTER_EVENTS_FILL            6
-#define NS_STYLE_POINTER_EVENTS_STROKE          7
-#define NS_STYLE_POINTER_EVENTS_ALL             8
+// image-rendering
+#define NS_STYLE_IMAGE_RENDERING_AUTO             0
+#define NS_STYLE_IMAGE_RENDERING_OPTIMIZESPEED    1
+#define NS_STYLE_IMAGE_RENDERING_OPTIMIZEQUALITY  2
+#define NS_STYLE_IMAGE_RENDERING_CRISPEDGES       3
 
 // shape-rendering
 #define NS_STYLE_SHAPE_RENDERING_AUTO               0
